@@ -20,7 +20,10 @@ package
 package PkgConfig;
 
 #First two digits are Perl version, second two are pkg-config version
-our $VERSION = '0.08726';
+our $VERSION = '0.09026';
+
+$VERSION =~ /([0-9]{2})$/;
+my $compat_version = $1;
 
 use strict;
 use warnings;
@@ -80,6 +83,31 @@ if($ENV{PKG_CONFIG_NO_OS_CUSTOMIZATION}) {
 
     @DEFAULT_SEARCH_PATH = split $Config{path_sep}, $ENV{PKG_CONFIG_LIBDIR};
 
+} elsif($^O eq 'solaris' && $Config{ptrsize} == 8) {
+
+    @DEFAULT_SEARCH_PATH = qw(
+        /usr/local/lib/64/pkgconfig /usr/local/share/pkgconfig
+        /usr/lib/64/pkgconfig /usr/share/pkgconfig
+    );
+
+} elsif($^O eq 'linux' and -f '/etc/gentoo-release') {
+    # OK, we're running on Gentoo
+
+    # Fetch ptrsize value
+    my $ptrsize = $Config{ptrsize};
+
+    # Are we running on 64 bit system?
+    if ($ptrsize eq 8) {
+        # We do
+        @DEFAULT_SEARCH_PATH = qw!
+          /usr/lib64/pkgconfig/ /usr/share/pkgconfig/
+        !;
+    } else {
+        # We're running on a 32 bit system (hopefully)
+        @DEFAULT_SEARCH_PATH = qw!
+          /usr/lib/pkgconfig/ /usr/share/pkgconfig/
+        !;
+    }
 } elsif($^O =~ /^(gnukfreebsd|linux)$/ && -r "/etc/debian_version") {
 
     my $arch;
@@ -1035,11 +1063,13 @@ GetOptions(
     'cflags-only-other' => \my $PrintCflagsOnlyOther,
     'exists' => \my $PrintExists,
     'atleast-version=s' => \my $AtLeastVersion,
+    'atleast-pkgconfig-version=s' => \my $AtLeastPkgConfigVersion,
     'exact-version=s'   => \my $ExactVersion,
     'max-version=s'     => \my $MaxVersion,
 
     'silence-errors' => \my $SilenceErrors,
     'print-errors' => \my $PrintErrors,
+    'errors-to-stdout' => \my $ErrToStdOut,
     
     'define-variable=s', => \my %UserVariables,
     
@@ -1076,10 +1106,18 @@ if($GuessPaths) {
 }
 
 if($PrintAPIversion) {
-    print "0.26\n";
+    print '0.', $compat_version, "\n";
     exit(0);
 }
 
+if($AtLeastPkgConfigVersion) {
+    my($major,$minor,$patch) = split /\./, $AtLeastPkgConfigVersion;
+    exit 1 if $major > 0;
+    exit 1 if $minor > $compat_version;
+    exit 1 if $minor == $compat_version && $patch > 0;
+    exit 0;
+}
+
 if($PrintRealVersion) {
 
     printf STDOUT ("ppkg-config - cruftless pkg-config\n" .
@@ -1090,10 +1128,20 @@ if($PrintRealVersion) {
 if($PrintErrors) {
     $quiet_errors = 0;
 }
+
 if($SilenceErrors) {
     $quiet_errors = 1;
 }
 
+# This option takes precedence over all other options
+# be it:
+# --silence-errors
+# or
+# --print-errors
+if ($ErrToStdOut) {
+ $quiet_errors = 2;
+}
+
 my $WantFlags = ($PrintCflags || $PrintLibs || $PrintLibsOnlyL || $PrintCflagsOnlyI || $PrintCflagsOnlyOther || $PrintLibsOnlyOther || $PrintLibsOnlyl || $PrintVersion);
 
 if($WantFlags) {
@@ -1145,7 +1193,14 @@ if($AtLeastVersion) {
 my $o = PkgConfig->find(\@FINDLIBS, %pc_options);
 
 if($o->errmsg) {
-    print STDERR $o->errmsg unless $quiet_errors;
+    # --errors-to-stdout
+    if ($quiet_errors eq 2) {
+        print STDOUT $o->errmsg;
+    # --print-errors
+    } elsif ($quiet_errors eq 1) {
+        print STDERR $o->errmsg;
+    }
+    # --silence-errors
     exit(1);
 }
 
@@ -1376,10 +1431,13 @@ arguments
 
 =head4 --print-errors
 
-This makes all errors noisy and takes precedence over
+Print errors to STDERR and takes precedence over
 C<--silence-errors>
 
+=head4 --errors-to-stdout
 
+Print errors to STDOUT and takes precedence over
+C<--print-errors>
 
 =head3 ENVIRONMENT
 
